@@ -1,5 +1,5 @@
 package Test::Expr;
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 use 5.014; use warnings;
 use Keyword::Declare;
@@ -22,7 +22,7 @@ sub import {
     $package->export_to_level(1, @_);
 
     keyword ok (Expr $test) {{{
-        ok «$test», q{«$test»};
+        ok do{«$test»}, q{«$test»};
     }}}
 
     keyword ok (ListElem $test, Comma, ListElem $desc) {
@@ -48,7 +48,7 @@ sub import {
             else {
                 fail($desc); @diagnostics diag q{};
             }
-        } =~ s{\n}{}gr;
+        };
     }
 }
 
@@ -62,7 +62,7 @@ Test::Expr - Test an expression with better error messages
 
 =head1 VERSION
 
-This document describes Test::Expr version 0.000002
+This document describes Test::Expr version 0.000003
 
 
 =head1 SYNOPSIS
